<?php 
ini_set('date.timezone','Asia/Shanghai');
require_once "../lib/DzPay.Api.php";
require_once "DzPay.PublicPay.php";

$input = new WXPublic();
$input->SetProductName("测试样例");
$input->SetProductDescription('公众号');
$input->SetAmount("0.01");
$input->SetMerchantOrderNo(date("YmdHis"));
$input->SetPromptView("1");
$input->SetReturnUrl(DzPayConfig::RETURN_URL);
$input->SetWechatAppId("");
$input->SetBuyerId("");

$publicPay = new PublicPay();
$jsApiParameters = $publicPay->pay($input,true);
?>